@@ -12,8 +12,8 @@ order.params <- function(samples,parameters.to.save,DIC,verbose=TRUE){
     DIC <- FALSE
   } 
   
-  samples <- samples[,params]
+  samples <- samples[,params, drop=FALSE]
   
   return(samples)
   
-}
\ No newline at end of file
+}
